@@ -9,42 +9,43 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("3.0.") or
-    raise "ruby lib version (3.0.7) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("3.1.") or
+    raise "ruby lib version (3.1.7) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby3.0/3.0.0/x86_64-darwin16")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby3.1/3.1.0/x86_64-darwin16")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
-  CONFIG["MINOR"] = "0"
+  CONFIG["MINOR"] = "1"
   CONFIG["TEENY"] = "7"
-  CONFIG["PATCHLEVEL"] = "220"
+  CONFIG["PATCHLEVEL"] = "261"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)3.0"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)3.0"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)3.1"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)3.1"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME).$(RUBY_API_VERSION)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.0.pc"
+  CONFIG["ruby_pc"] = "ruby-3.1.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
+  CONFIG["MKMF_VERBOSE"] = "0"
   CONFIG["MANTYPE"] = "doc"
   CONFIG["vendorarchhdrdir"] = "$(vendorhdrdir)/$(sitearch)"
   CONFIG["sitearchhdrdir"] = "$(sitehdrdir)/$(sitearch)"
   CONFIG["rubyarchhdrdir"] = "$(rubyhdrdir)/$(arch)"
   CONFIG["vendorhdrdir"] = "$(rubyhdrdir)/vendor_ruby"
   CONFIG["sitehdrdir"] = "$(rubyhdrdir)/site_ruby"
-  CONFIG["rubyhdrdir"] = "$(includedir)/$(RUBY_VERSION_NAME)"
+  CONFIG["rubyhdrdir"] = "$(DESTDIR)/opt/local/include/ruby-3.1.7"
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-gmp' '--with-opt-dir=/opt/local' '--program-suffix=3.0' '--with-rubylibprefix=/opt/local/lib/ruby3.0' '--with-openssl-dir=/opt/local/libexec/openssl11' '--without-baseruby' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' '--with-arch=x86_64' 'CC=/opt/local/bin/clang-mp-17' 'CXX=/opt/local/bin/clang++-mp-17' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++ -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -isystem/opt/local/include' 'CFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -arch x86_64'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-gmp' '--with-opt-dir=/opt/local' '--program-suffix=3.1' '--with-rubyhdrdir=/opt/local/include/ruby-3.1.7' '--with-rubylibprefix=/opt/local/lib/ruby3.1' '--with-openssl-dir=/opt/local/libexec/openssl11' '--without-baseruby' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' '--with-arch=x86_64' 'CC=/opt/local/bin/clang-mp-16' 'CXX=/opt/local/bin/clang++-mp-16' 'CFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -isystem/opt/local/include' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++ -arch x86_64'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -54,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "3.0.0"
+  CONFIG["ruby_version"] = "3.1.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "x86_64-darwin16"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -83,7 +84,7 @@ module RbConfig
   CONFIG["DLDLIBS"] = ""
   CONFIG["SOLIBS"] = "$(MAINLIBS)"
   CONFIG["LIBRUBYARG_SHARED"] = "-l$(RUBY_SO_NAME)"
-  CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static -framework Security -framework Foundation $(MAINLIBS)"
+  CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static -framework CoreFoundation $(MAINLIBS)"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_INSTALL_NAME).$(SOEXT)"
@@ -95,9 +96,9 @@ module RbConfig
   CONFIG["EXTDLDFLAGS"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = "-std=gnu99"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdivision-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wextra-tokens"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdivision-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wold-style-definition -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wextra-tokens -Wundef"
   CONFIG["debugflags"] = "-ggdb3"
-  CONFIG["optflags"] = "-O3"
+  CONFIG["optflags"] = "-O3 -fno-fast-math"
   CONFIG["NULLCMD"] = ":"
   CONFIG["ENABLE_DEBUG_ENV"] = ""
   CONFIG["DLNOBJ"] = "dln.o"
@@ -107,10 +108,10 @@ module RbConfig
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "no"
   CONFIG["EXTOUT"] = ".ext"
-  CONFIG["PREP"] = "miniruby$(EXEEXT) exe/$(PROGRAM)"
+  CONFIG["PREP"] = "miniruby$(EXEEXT)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
-  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby3.0"
+  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby3.1"
   CONFIG["setup"] = "Setup"
   CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
@@ -124,20 +125,21 @@ module RbConfig
   CONFIG["ADDITIONAL_DLDFLAGS"] = ""
   CONFIG["ASMEXT"] = "S"
   CONFIG["LIBEXT"] = "a"
-  CONFIG["DLEXT2"] = ""
   CONFIG["DLEXT"] = "bundle"
   CONFIG["LDSHAREDXX"] = "$(CXX) -dynamic -bundle"
   CONFIG["LDSHARED"] = "$(CC) -dynamic -bundle"
   CONFIG["CCDLFLAGS"] = "-fno-common"
   CONFIG["STATIC"] = ""
   CONFIG["ARCH_FLAG"] = " -arch x86_64"
-  CONFIG["DLDFLAGS"] = "-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64 -Wl,-multiply_defined,suppress -Wl,-undefined,dynamic_lookup -L/opt/local/lib"
+  CONFIG["DLDFLAGS"] = "-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64 -L/opt/local/lib -Wl,-multiply_defined,suppress -Wl,-undefined,dynamic_lookup"
   CONFIG["ALLOCA"] = ""
   CONFIG["EGREP"] = "/usr/bin/grep -E"
   CONFIG["GREP"] = "/usr/bin/grep"
-  CONFIG["dsymutil"] = "dsymutil"
+  CONFIG["dsymutil"] = "/opt/local/bin/dsymutil-mp-16"
   CONFIG["codesign"] = "codesign"
-  CONFIG["POSTLINK"] = "dsymutil $@; { test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@; }"
+  CONFIG["cleanlibs"] = "$(TARGET_SO).dSYM"
+  CONFIG["POSTLINK"] = "/opt/local/bin/dsymutil-mp-16 $@; { test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@; }"
+  CONFIG["incflags"] = "-I/opt/local/include"
   CONFIG["WERRORFLAG"] = "-Werror"
   CONFIG["CHDIR"] = "cd -P"
   CONFIG["RMALL"] = "rm -fr"
@@ -160,31 +162,31 @@ module RbConfig
   CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcu "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "clang version 17.0.6\nTarget: x86_64-apple-darwin16.7.0\nThread model: posix\nInstalledDir: /opt/local/libexec/llvm-17/bin"
+  CONFIG["CC_VERSION_MESSAGE"] = "clang version 16.0.6\nTarget: x86_64-apple-darwin16.7.0\nThread model: posix\nInstalledDir: /opt/local/libexec/llvm-16/bin"
   CONFIG["CC_VERSION"] = "$(CC) --version"
-  CONFIG["MJIT_CC"] = "/opt/local/bin/clang-mp-17 -fdeclspec"
+  CONFIG["MJIT_CC"] = "/opt/local/bin/clang-mp-16"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
   CONFIG["OUTFLAG"] = "-o "
   CONFIG["CPPOUTFILE"] = "-o conftest.i"
   CONFIG["GNU_LD"] = "no"
   CONFIG["GCC"] = "yes"
-  CONFIG["CPP"] = "/opt/local/bin/clang-mp-17 -E"
-  CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -fno-common"
+  CONFIG["CPP"] = "$(CC) -E"
+  CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++ -fdeclspec"
   CONFIG["OBJEXT"] = "o"
-  CONFIG["CPPFLAGS"] = "-I/opt/local/libexec/openssl11/include -isystem/opt/local/include -I/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -fstack-protector-strong -L/opt/local/libexec/llvm-17/lib/clang/17/lib -L/opt/local/lib"
-  CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++"
+  CONFIG["CPPFLAGS"] = "-I/opt/local/libexec/openssl11/include -isystem/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT $(DEFS) $(cppflags)"
+  CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -fstack-protector-strong -L/opt/local/lib -L/opt/local/libexec/llvm-16/lib/clang/16/lib"
+  CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os $(cflags) -fno-common"
   CONFIG["STRIP"] = "strip -A -n"
   CONFIG["RANLIB"] = "/opt/local/bin/ranlib"
   CONFIG["OBJDUMP"] = "objdump"
   CONFIG["OBJCOPY"] = ":"
-  CONFIG["NM"] = "nm"
-  CONFIG["LD"] = "/opt/local/bin/clang-mp-17"
-  CONFIG["CXX"] = "/opt/local/bin/clang++-mp-17 -fdeclspec"
+  CONFIG["NM"] = "/opt/local/bin/nm"
+  CONFIG["LD"] = "/opt/local/bin/clang-mp-16"
+  CONFIG["CXX"] = "/opt/local/bin/clang++-mp-16"
   CONFIG["AS"] = "as"
   CONFIG["AR"] = "/opt/local/bin/ar"
-  CONFIG["CC"] = "/opt/local/bin/clang-mp-17 -fdeclspec"
+  CONFIG["CC"] = "/opt/local/bin/clang-mp-16"
   CONFIG["target_os"] = "darwin16"
   CONFIG["target_vendor"] = "apple"
   CONFIG["target_cpu"] = "x86_64"
@@ -206,7 +208,7 @@ module RbConfig
   CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
-  CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cflags"] = "-fdeclspec $(optflags) $(debugflags) $(warnflags)"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
@@ -224,8 +226,8 @@ module RbConfig
   CONFIG["htmldir"] = "$(docdir)"
   CONFIG["infodir"] = "$(datarootdir)/info"
   CONFIG["docdir"] = "$(datarootdir)/doc/$(PACKAGE)"
-  CONFIG["oldincludedir"] = "$(SDKROOT)""/usr/include"
-  CONFIG["includedir"] = "$(prefix)/include"
+  CONFIG["oldincludedir"] = "/usr/include"
+  CONFIG["includedir"] = "$(SDKROOT)""$(prefix)/include"
   CONFIG["runstatedir"] = "$(localstatedir)/run"
   CONFIG["localstatedir"] = "$(prefix)/var"
   CONFIG["sharedstatedir"] = "$(prefix)/com"
@@ -235,7 +237,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&3.0&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&3.1&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
@@ -245,9 +247,10 @@ module RbConfig
   CONFIG["PACKAGE_NAME"] = ""
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["UNICODE_VERSION"] = "12.1.0"
-  CONFIG["UNICODE_EMOJI_VERSION"] = "12.1"
-  CONFIG["SDKROOT"] = "#{ENV['SDKROOT']}" # don't run xcrun every time, usually useless.
+  CONFIG["UNICODE_VERSION"] = "13.0.0"
+  CONFIG["UNICODE_EMOJI_VERSION"] = "13.1"
+  CONFIG["SDKROOT"] = ""
+  CONFIG["platform"] = "$(arch)"
   CONFIG["archdir"] = "$(rubyarchdir)"
   CONFIG["topdir"] = File.dirname(__FILE__)
   # Almost same with CONFIG. MAKEFILE_CONFIG has other variable
